68a21741ea6388775442314e7e71e98c7a15adad
hiram
  Sat Oct 15 22:29:42 2022 -0700
rail para job ram size to 32g to avoid crashes due to out of memory no redmine

diff --git src/hg/utils/automation/doTandemDup.pl src/hg/utils/automation/doTandemDup.pl
index 343d6b2..d83e387 100755
--- src/hg/utils/automation/doTandemDup.pl
+++ src/hg/utils/automation/doTandemDup.pl
@@ -176,32 +176,32 @@
   if ( ! $opt_debug && ( ! -s "$prevRunDir/run.time" ) ) {
     die "pairedEnds: looks like previous kmers step has not been competed, " .
       "file db/bed/tandemDups/kmers/run.time does not exist. run with: -continue kmers to perform previous step.\n";
   }
 
   &HgAutomate::mustMkdir($runDir);
 
   my $templateCmd = ("runOne $kmersMinus1 $gapSize " . '$(path1) {check out exists tmp/$(path1).bed.gz}');
   &HgAutomate::makeGsub($runDir, $templateCmd);
   `touch "$runDir/para_hub_$paraHub"`;
 
   my $whatItDoes = "Collect kmers into pairs.";
   my $bossScript = newBash HgRemoteScript("$runDir/runPairedEnds.bash",
 		$paraHub, $runDir, $whatItDoes);
 
-  # trying 16G ram to see if jobs will not fail
-  my $paraRun = "para make -ram=16g jobList
+  # trying 32G ram to see if jobs will not fail
+  my $paraRun = "para make -ram=32g jobList
 para check
 para time > run.time
 cat run.time\n";
 
   $bossScript->add(<<_EOF_
 ln -s $prevRunDir/part.list .
 printf '#!/bin/bash
 
 set -beEu -o pipefail
 
 export kmerSize=\$1
 export gapSize=\$2
 export chrName=\$3
 export result=\$4
 
@@ -233,32 +233,32 @@
   if ( ! $opt_debug && ( ! -s "$prevRunDir/run.time" ) ) {
     die "pairedEnds: looks like previous pairedEnds step has not been competed, " .
       "file db/bed/tandemDups/pairedEnds/run.time does not exist. run with: -continue pairedEnds to perform previous step.\n";
   }
 
   &HgAutomate::mustMkdir($runDir);
 
   my $templateCmd = ('runOne $(path1) {check out exists tmp/$(path1).bed.gz}');
   &HgAutomate::makeGsub($runDir, $templateCmd);
   `touch "$runDir/para_hub_$paraHub"`;
 
   my $whatItDoes = "Collapse kmers pairs into larger paired ends.";
   my $bossScript = newBash HgRemoteScript("$runDir/runCollapsePairedEnds.bash",
 		$paraHub, $runDir, $whatItDoes);
 
-  # trying 16G ram to see if jobs will not fail
-  my $paraRun = "para make -ram=16g jobList
+  # trying 32G ram to see if jobs will not fail
+  my $paraRun = "para make -ram=32g jobList
 para check
 para time > run.time
 cat run.time\n";
 
   $bossScript->add(<<_EOF_
 ln -s $prevRunDir/part.list .
 printf '#!/bin/bash
 
 set -beEu -o pipefail
 
 export chrName=\$1
 export result=\$2
 mkdir -p tmp
 
 $Bin/kmerCollapsePairedEnds.pl $kmersMinus1 ../pairedEnds/tmp/\$chrName.bed.gz \\